pub enum MatrixError {
ShapeMismatch {
first_matrix_shape: String,
second_matrix_shape: String,
},
DivideByZero,
IllegalRange(String),
MatrixMultiply,
}Expand description
Custom Error type for a Matrix operation
Variants
ShapeMismatch
An error that occurs when a operation requires that two matrices have the exact same shape
Fields
DivideByZero
Operation lead to division by 0
IllegalRange(String)
Matrix operation required a range, but the given range lead to an error,
MatrixMultiply
Matrix multiplication with two given matrixes sizes (mxn) and (qxp) The columns (n) must equal rows (q) => n == q